pub fn check_latitude(latitude: f64) -> Result<f64, MortonError>Expand description
Validate latitude, which is clamped into the grid rather than wrapped.
pub fn check_latitude(latitude: f64) -> Result<f64, MortonError>Validate latitude, which is clamped into the grid rather than wrapped.